// MAFW Dbus connect string
#define MAFW_METADATA_PATH "/com/nokia/mafw/renderer/gstrenderer"
#define MAFW_METADATA_IF   "com.nokia.mafw.renderer"
#define MAFW_EXTENSION_IF   "com.nokia.mafw.extension"
//
#define RTCOM_CSD_PATH  "/com/nokia/csd/call"
#define RTCOM_CSD_IF   "com.nokia.csd.Call"
#define RTCOM_CSD_INST_IF   "com.nokia.csd.Call.Instance"

#define FMTX_PATH "/com/nokia/fmtx/default"
#define FMTX_IF "com.nokia.policy"
